@@ -76,6 +76,7 @@ QHash<int, QByteArray> DataModel::roleNames() const
     roles[static_cast<int>(DataTypes::ColumnsRoles::TitleRole)] = "title";
     roles[static_cast<int>(DataTypes::ColumnsRoles::SecondaryTextRole)] = "secondaryText";
     roles[static_cast<int>(DataTypes::ColumnsRoles::ImageUrlRole)] = "imageUrl";
+    roles[static_cast<int>(DataTypes::ColumnsRoles::MultipleImageUrlsRole)] = "multipleImageUrls";
     roles[static_cast<int>(DataTypes::ColumnsRoles::DatabaseIdRole)] = "databaseId";
     roles[static_cast<int>(DataTypes::ColumnsRoles::ElementTypeRole)] = "dataType";
     roles[static_cast<int>(DataTypes::ColumnsRoles::ResourceRole)] = "url";
@@ -153,6 +154,7 @@ QVariant DataModel::data(const QModelIndex &index, int role) const
         case ElisaUtils::FileName:
         case ElisaUtils::Container:
         case ElisaUtils::Unknown:
+        case ElisaUtils::PlayList:
             break;
         }
         break;
@@ -179,6 +181,7 @@ QVariant DataModel::data(const QModelIndex &index, int role) const
         case ElisaUtils::Radio:
         case ElisaUtils::Container:
         case ElisaUtils::Unknown:
+        case ElisaUtils::PlayList:
             break;
         }
         break;
@@ -203,6 +206,7 @@ QVariant DataModel::data(const QModelIndex &index, int role) const
         case ElisaUtils::FileName:
         case ElisaUtils::Container:
         case ElisaUtils::Unknown:
+        case ElisaUtils::PlayList:
             break;
         }
         break;
@@ -238,6 +242,7 @@ QVariant DataModel::data(const QModelIndex &index, int role) const
         case ElisaUtils::FileName:
         case ElisaUtils::Container:
         case ElisaUtils::Unknown:
+        case ElisaUtils::PlayList:
             break;
         }
         break;
@@ -265,6 +270,7 @@ QVariant DataModel::data(const QModelIndex &index, int role) const
         case ElisaUtils::FileName:
         case ElisaUtils::Container:
         case ElisaUtils::Unknown:
+        case ElisaUtils::PlayList:
             break;
         }
         break;
@@ -286,6 +292,7 @@ QVariant DataModel::data(const QModelIndex &index, int role) const
         case ElisaUtils::Composer:
         case ElisaUtils::Container:
         case ElisaUtils::Unknown:
+        case ElisaUtils::PlayList:
             result = QUrl{};
             break;
         }
@@ -307,6 +314,7 @@ QVariant DataModel::data(const QModelIndex &index, int role) const
         case ElisaUtils::Lyricist:
         case ElisaUtils::Composer:
         case ElisaUtils::Container:
+        case ElisaUtils::PlayList:
             result = true;
             break;
         }
@@ -335,6 +343,7 @@ QVariant DataModel::data(const QModelIndex &index, int role) const
         case ElisaUtils::FileName:
         case ElisaUtils::Container:
         case ElisaUtils::Unknown:
+        case ElisaUtils::PlayList:
             break;
         }
     }
